isDesktop property
bool
get
isDesktop
Returns true if the platform is a desktop system (Linux, macOS, or Windows).
Implementation
static bool get isDesktop => isLinux || isMacOS || isWindows;
Returns true if the platform is a desktop system (Linux, macOS, or Windows).
static bool get isDesktop => isLinux || isMacOS || isWindows;