isWeb property
bool
get
isWeb
Returns true if the platform is a web browser.
Implementation
static bool get isWeb =>
DevicePlatformType.currentPlatformType == PlatformType.Web;
Returns true if the platform is a web browser.
static bool get isWeb =>
DevicePlatformType.currentPlatformType == PlatformType.Web;